.. _user_guide_joining_dataframes:

Joining Dataframes
==================

This section covers the various methods provided by skrub to join dataframes.

.. toctree::
   :maxdepth: 3

   modules/joining_tables/assembling
